#!/usr/bin/sh

####################################################################################################
# Uninstallation script for FireScope Agent for Solaris Sparc
####################################################################################################

####################################################################################################
# Variables
####################################################################################################
VERSION="3.6"
FSUSER="firescop"
FSGROUP="firescop"
INSTALLDIR=INSTALLDIR
INIT=INIT
WHOAMI=`id | cut -d "(" -f2 | cut -d ")" -f1`
UNINSTALLERLOG="/var/tmp/firescope_agent_uninstall.log"
echo "\033[40m\033[40;33m" #sets back gound to black
####################################################################################################
#Check if user is root
####################################################################################################
	echo "****************************Checking User Permission for Agent Uninstall***************************" >>$UNINSTALLERLOG
	if [ "${WHOAMI}" != "root" ]; then
		echo "Sorry, root required to uninstall agent."
		exit 1
	fi
####################################################################################################
#End Check if user is root
####################################################################################################
OSVER=`uname -r`
if [ $OSVER = "5.10" ];
then
	echo $OSVER >>$UNINSTALLERLOG
else
	echo "NOT 10" >>$UNINSTALLERLOG
fi
####################################################################################################
# Check Solaris version and setup Init apropriately
####################################################################################################
echo "****************************Checking OSVersion ***************************" >>$UNINSTALLERLOG
echo "OS Version: $OSVER" >>$UNINSTALLERLOG
if [ $OSVER = "5.10" ];
then
	####################################################################################################
	# disabling SMF service
	####################################################################################################
	echo "****************************Stopping svc FireScope Services ***************************" >>$UNINSTALLERLOG
		svcadm disable firescope_agentd
		svcadm disable firescope_agent_managerd
		sleep 5
	####################################################################################################
	# unregistering SMF service
	####################################################################################################
	echo "****************************Removing svc FireScope Services ***************************" >>$UNINSTALLERLOG
		svccfg delete -f application/firescope_agentd
		svccfg delete -f application/firescope_agent_managerd
	####################################################################################################
	# cleanup old SMF config files
	####################################################################################################
	rm -rf /var/svc/manifest/application/firescope_agentd.xml
	rm -rf /lib/svc/method/firescope_agentd	
	rm -rf /var/svc/manifest/application/firescope_agent_managerd.xml
	rm -rf /lib/svc/method/firescope_agent_managerd	
else
	####################################################################################################
	# Kill all FireScope processes
	####################################################################################################
	# pkill -15 -u $FSUSER
	echo "****************************Stopping FireScope Services ***************************" >>$UNINSTALLERLOG
	echo "$INIT/firescope_agentd stop" >>$UNINSTALLERLOG
		"$INIT"/firescope_agentd stop
	echo "$INIT/firescope_agent_managerd stop" >>$UNINSTALLERLOG
		$INIT/firescope_agent_managerd stop
		sleep 5
	####################################################################################################
	# Remove FireScope files and folders
	####################################################################################################
	echo "****************************Removing FireScope Services ***************************" >>$UNINSTALLERLOG
		rm -f $INIT/firescope_agentd
		rm -f /etc/rc0.d/K50firescope_agentd
		rm -f /etc/rcS.d/K50firescope_agentd
		rm -f /etc/rcS.d/S50firescope_agentd
		rm -f /etc/rc1.d/S50firescope_agentd
		rm -f /etc/rc2.d/S50firescope_agentd
		rm -f /etc/rc3.d/S50firescope_agentd
		rm -f /etc/rc4.d/K50firescope_agentd
		rm -f /etc/rc5.d/K50firescope_agentd
		rm -f /etc/rc6.d/K50firescope_agentd
		rm -f $INIT/firescope_agent_managerd
		rm -f /etc/rc0.d/K50firescope_agent_managerd
		rm -f /etc/rcS.d/K50firescope_agent_managerd
		rm -f /etc/rcS.d/S50firescope_agent_managerd
		rm -f /etc/rc1.d/S50firescope_agent_managerd
		rm -f /etc/rc2.d/S50firescope_agent_managerd
		rm -f /etc/rc3.d/S50firescope_agent_managerd
		rm -f /etc/rc4.d/K50firescope_agent_managerd
		rm -f /etc/rc5.d/K50firescope_agent_managerd
		rm -f /etc/rc6.d/K50firescope_agent_managerd
fi
	rm -rf $INSTALLDIR
	####################################################################################################
	# Remove firescop from operating system
	####################################################################################################
	echo "****************************Removing FireScope Agent User and Group ***************************" >>$UNINSTALLERLOG
userdel $FSUSER
groupdel $FSGROUP
	echo "**************************** Uninstall Completed ***************************" >>$UNINSTALLERLOG
####################################################################################################
# DONE
####################################################################################################
echo "FireScope Agent for Solaris Sparc has been removed."
echo "\033[0m" # sets background back to default
exit 0